// gfx.cpp

#include "SDL/SDL.h" 
#include <windows.h>
#include <GL/gl.h>
#include <GL/glu.h>

SDL_Surface *pscreen=0; 
static int bpp = 32;
static int fb_w, fb_h;

bool InitGfx(int width, int height, bool fullscreen)
{
	if (static bool firsttime=true)
	{
		if (SDL_Init(SDL_INIT_VIDEO))
			return false;
		firsttime=false;
	}

	if (pscreen) SDL_FreeSurface(pscreen);

	SDL_GL_SetAttribute(SDL_GL_RED_SIZE,8);
	SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE,8);
	SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE,8);
	SDL_GL_SetAttribute(SDL_GL_ALPHA_SIZE,8);
	SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE,16);
	SDL_GL_SetAttribute(SDL_GL_STENCIL_SIZE,4);
	SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER,1);

	if (fullscreen)
	{
		pscreen = SDL_SetVideoMode(width,height,bpp,SDL_OPENGL | SDL_FULLSCREEN);
	}
	else
	{
		pscreen = SDL_SetVideoMode(width,height,bpp,SDL_OPENGL);
	}

	if (!pscreen) return false;

	fb_w = width; fb_h = height;

	glClearColor(0,0,0,0);
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
	
	glDepthFunc(GL_ALWAYS);
	glEnable(GL_LINE_SMOOTH);

	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	//glViewport(0,0,640,480);
	gluOrtho2D(0, width, 0, height);

	SDL_WM_SetCaption("Headtrack" , "default");

	return true;
}

void FlipGfx()
{
	SDL_GL_SwapBuffers();
}

void CloseGfx()
{
	if (pscreen) SDL_FreeSurface(pscreen);
	pscreen = 0;
}

void BlitImage(int w, int h, void *pixels,
			   int x, int y, int dstw, int dsth)
{
	glRasterPos2i(x, fb_h - y);
	glPixelZoom((float) dstw / (float) w, -(float) dsth / (float) h);
	glDrawPixels(w, h, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
}

void PutRect(int x1, int y1, int x2, int y2, int r, int g, int b)
{
	y1 = fb_h - y1;
	y2 = fb_h - y2;
	glBegin(GL_QUADS);
	glColor3f(r/255.0f, g/255.0f, b/255.0f);
	glVertex2f(x1, y1);
	glVertex2f(x1, y2);
	glVertex2f(x2, y2);
	glVertex2f(x2, y1);
	glEnd();
}

