// main.cpp
#include <stdio.h>
#include <windows.h>
#include <GL/gl.h>
#include <GL/glu.h>
#include "capture.h"
#include "gfx.h"
#include "events.h"
#include "cluster.h"
#include <math.h>

void Redraw();
bool Init();
void Shutdown();

unsigned char *image=0;
int w=0, h=0;

int main(int argc, char **argv)
{
	if (!Init())
	{
		printf("E: exiting...\n");
		return 1;
	}
	
	while (ProcessEvents())
	{
		Redraw();
		FlipGfx();
	}

	Shutdown();

	return 0;
}

bool Init()
{
	if (!StartCam()) return false;
	if (!InitGfx(800, 600, false))
	{
		StopCam();
		return false;
	}

	return true;
}

void GetNewImage()
{
	if (GetCamWidth() > w || GetCamHeight() > h)
	{
		w = GetCamWidth();
		h = GetCamHeight();
		if (image) free(image);
		image = (unsigned char*) malloc(4 * w * h);
	}
	memcpy(image, BeginCamData(), 4 * w * h);
	EndCamData();
}

void Redraw()
{
	if (NewCamData())
	{
		glClear(GL_COLOR_BUFFER_BIT);

		GetNewImage();
		std::vector<Cluster> clusts = ClusterImage(w, h, image,127, 0, 0, 50 * 255);

		BlitImage(w, h, image, 0, 0, 800, 600);
		Cluster cl;
		cl.cx = cl.cy = 0;
		cl.sample_count = 0;
		for (unsigned int i=0; i<clusts.size(); i++)
		{
			cl.cx += clusts[i].cx * clusts[i].sample_count;
			cl.cy += clusts[i].cy * clusts[i].sample_count;
			cl.sample_count += clusts[i].sample_count;
		}
		cl.cx /= cl.sample_count;
		cl.cy /= cl.sample_count;
		cl.w = cl.h = sqrt((float)cl.sample_count);
		cl.x = cl.cx - cl.w / 2;
		cl.y = cl.cy - cl.h / 2;

		PutRect(cl.x, cl.y, cl.x + cl.w, cl.y + cl.h, 0, 0, 255);
	}
	else
	{
		//Sleep(1);
	}
}

void Shutdown()
{
	CloseGfx();
	StopCam();
}
